# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

"""Help documentation for `app` commands."""

from knack.help_files import helps
from azdata.cli.commands.app import _

helps['app'] = """
    type: group
    short-summary: {short}    
""".format(short=_('Create, delete, run, and manage applications.'))

helps['app template'] = """
    type: group
    short-summary: {short}
""".format(short=_('Templates.'))

helps['app template list'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app template list
        - name: {ex2}
          text: >
            azdata app template list --url https://github.com/diffrent/templates.git
""".format(
    short=_('Fetch supported templates.'),
    long=_('Fetch supported templates under the specified [URL] github '
           'repository.'),
    ex1=_('Fetch all templates under the default template repository '
          'location.'),
    ex2=_('Fetch all templates under a different repository location.'))

helps['app template pull'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app template pull
        - name: {ex2}
          text: >
            azdata app template list --url https://github.com/diffrent/templates.git
        - name: {ex3}
          text: >
            azdata app template pull --name ssis            
""".format(
    short=_('Download supported templates.'),
    long=_('Download supported templates under the specified [URL] github '
           'repository.'),
    ex1=_('Download all templates under the default template repository '
          'location.'),
    ex2=_('Download all templates under a different repository location.'),
    ex3=_('Download individual template by name.'))

helps['app init'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app init --spec
        - name: {ex2}
          text: >
            azdata app init --name reduce --template r
        - name: {ex3}
          text: >
            azdata app init --name reduce --template python
        - name: {ex4}
          text: >
            azdata app init --name reduce --template ssis            
""".format(
    short=_('Kickstart new application skeleton.'),
    long=_('Helps you to kickstart new application skeleton and/or spec files '
           'based on runtime environments.'),
    ex1=_('Scaffold a new application `spec.yaml` only.'),
    ex2=_('Scaffold a new R application application skeleton based on the `r` '
          'template.'),
    ex3=_('Scaffold a new Python application application skeleton based on the '
          '`python` template.'),
    ex4=_('Scaffold a new SSIS application application skeleton based on the '
          '`ssis` template.'))

helps['app create'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app create --spec /path/to/dir/with/spec/yaml
""".format(
    short=_('Create application.'),
    long=_('Create an application.'),
    ex1=_('Create a new application from a directory containing a valid '
          'spec.yaml deployment specification.'))

helps['app update'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app update --spec /path/to/dir/with/spec/yaml    
""".format(
    short=_('Update application.'),
    long=_('Update an application.'),
    ex1=_('Update an existing application from a directory containing a valid '
          'spec.yaml deployment specification.'))


helps['app list'] = """
    type: command
    short-summary: {short}
    long-summary: {long},
    examples:
        - name: {ex1}
          text: >
            azdata app list --name reduce  --version v1
        - name: {ex2}
          text: >
            azdata app list --name reduce
        - name: {ex2}
          text: >
            azdata app list
""".format(
    short=_('List application(s).'),
    long=_('List an application(s).'),
    ex1=_('List application by name and version.'),
    ex2=_('List all application versions by name.'),
    ex3=_('List all applications.'))

helps['app delete'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app delete --name reduce --version v1    
""".format(
    short=_('Delete application.'),
    long=_('Delete an application.'),
    ex1=_('Delete application by name and version.'))

helps['app run'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app run --name reduce --version v1
        - name: {ex2}
          text: >
            azdata app run --name reduce --version v1 --inputs x=10
        - name: {ex3}
          text: >
            azdata app run --name reduce --version v1 --inputs x=10,y5.6    
""".format(
    short=_('Run application.'),
    long=_('Run an application.'),
    ex1=_('Run application with no input parameters.'),
    ex2=_('Run application with 1 input parameter.'),
    ex3=_('Run application with multiple input parameters.'))

helps['app describe'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata app describe --name reduce --version v1    
""".format(
    short=_('Describe application.'),
    long=_('Describe an application.'),
    ex1=_('Describe the application.'))
