# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.app.spec import Spec
from azdata.cli.core.configuration import Configuration

import shutil
import os


class Scaffold(object):
    def __init__(self, name, version, runtime, destination):
        self._name = name
        self._version = version
        self._runtime = runtime
        self._destination = destination

    def generate(self, tpl_dir, spec_only=False):
        """
        Generate scaffold application from the given template.
        """
        parent_dir = os.path.abspath(os.path.join(tpl_dir, '..'))
        try:
            stage_dir = os.path.join(parent_dir, self._name)
            os.rename(tpl_dir, stage_dir)

            # -- update spec.yaml tpl with provided name/version --
            spec = Spec(stage_dir)
            spec.name = self._name
            spec.version = self._version
            spec.dump(stage_dir)

            target = stage_dir if not spec_only else \
                os.path.join(stage_dir, Spec.FILE)

            shutil.move(target, self._destination)
        finally:
            shutil.rmtree(parent_dir)
