# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.app.encoding_types import EncodingType
from azdata.cli.commands.app.constants import IO_DELIM
from azdata.cli.core.util import FileUtil
from azdata.cli.core.logging import get_logger

import re
import os

logger = get_logger(__name__)


def validate_inputs(ns):
    if ns.inputs:
        for param in re.split(IO_DELIM, ns.inputs):
            nv = param.strip().split('=')
            if len(nv) != 2:
                raise ValueError('Unbalanced name value pair "{}".'.
                                 format(ns.inputs))

            # Verify if value contains lnk `@` prefix and see if file exists
            # Example: name=@/path/to/file
            if FileUtil.is_lnk_path(nv[1]) and \
                    not os.path.isfile(FileUtil.strip_path(nv[1])):
                raise ValueError('No such file: "{}"'.format(nv[1]))


def validate_io(ns):
    def _validate(io, runtime, arg):
        try:
            for param in re.split(IO_DELIM, io):
                nv = param.strip().split('=')
                if len(nv) != 2:
                    raise ValueError('Unbalanced name value pair.')
                io_type = nv[1]

                # will throw error is runtime or runtime+type not supported
                EncodingType.cast_client_to_server_type(io_type, runtime)
        except Exception as e:
            msg = 'Error processing "{0}": "{1}." {2}'.format(arg, io, str(e))
            raise ValueError(msg)

    if ns.inputs:
        _validate(ns.inputs, ns.runtime, 'inputs')

    if ns.outputs:
        _validate(ns.outputs, ns.runtime, 'outputs')
