# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

"""
Entry or launch point for the CLI.

Handles creating and launching the CLI to handle a user commands.
"""

from azdata.cli.core import cli as cli_factory
from azdata.cli.core.logging import get_logger
import sys
import timeit


log = get_logger(__name__)


def launch():
    """
    Entry point for the CLI.

    Configures and invokes the CLI with arguments passed during the time the
    python session was initiated.
    """
    cli = None
    elapsed_time = -1
    start_time = timeit.default_timer()
    try:
        cli = cli_factory()
        exit_code = cli.invoke(sys.argv[1:])
        elapsed_time = timeit.default_timer() - start_time
        sys.exit(exit_code)
    except KeyboardInterrupt:
        sys.exit(1)
    except SystemExit as e:
        exit_code = e.code if e.code is not None else 1

        try:
            elapsed_time = timeit.default_timer() - start_time
        except Exception:  # load object that does not exist
            pass

        if cli:
            cli.logging.end_cmd_metadata_logging(exit_code)
        raise e
    finally:
        try:
            log.info('command ran in %.3f seconds.', elapsed_time)
        except NameError:  # load object that does not exist
            pass
